@@ -40,6 +40,7 @@ import urllib.parse
 from reprotest.lib.system_interface.debian import DebianInterface
 from reprotest.lib.system_interface.arch import ArchInterface
 from reprotest.lib.system_interface.fedora import FedoraInterface
+from reprotest.lib.system_interface.guix import GuixInterface
 from reprotest.lib import adtlog
 from reprotest.lib import VirtSubproc
 
@@ -47,6 +48,7 @@ SYSTEM_INTERFACES = {
         'debian': DebianInterface,
         'arch': ArchInterface,
         'fedora': FedoraInterface,
+        'guix': GuixInterface,
         }
 
 timeouts = {
@@ -209,10 +211,10 @@ class Testbed:
             cpu_info = self.check_exec(['sh', '-c', 'nproc; cat /proc/cpuinfo 2>/dev/null || true'],
                                        stdout=True).strip()
             self.nproc = cpu_info.split('\n', 1)[0]
-            m = re.search('^(model.*name|cpu)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
+            m = re.search(r'^(model.*name|cpu)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
             if m:
                 self.cpu_model = m.group(2)
-            m = re.search('^(flags|features)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
+            m = re.search(r'^(flags|features)\s*:\s*(.*)$', cpu_info, re.MULTILINE | re.IGNORECASE)
             if m:
                 self.cpu_flags = m.group(2)
 
